<?php

namespace Service;

use Util\Instance\RepositoryInstance;

class SupportOperator
{
    public function isSupportOperator($user, $password)
    {
        $operador = RepositoryInstance::getOperador()->getOperatorByNmAccessOrEmailSupportOperator($user);
        if(!empty($operador) && $this->validateSupportOperatorAccess($operador['DTLIMACESSOSUP'])) {
            return $operador;
        }
        return null;
    }

    /**
     * @param $date
     * @return bool
     */
    public function validateSupportOperatorAccess($date)
    {
        $currentDate = new \DateTime();
        $passwordValidate = \DateTime::createFromFormat('d/m/Y H:i:s', $date);
        return $passwordValidate > $currentDate;
    }

    public function getUserData($supportOperator, $password)
    {
        $userData = array( 'USER' => false );
        if(!empty($supportOperator) && $supportOperator['ID']) {
            $userData['USER']           = $supportOperator;
            $userData['ORGANIZATION']   = RepositoryInstance::getOrganizacao()->getOrganizacaoByNrorg($supportOperator['NRORGSUP']);
            if(!empty($userData['ORGANIZATION']) && !empty($userData['ORGANIZATION']['NRORGPRINCIPAL'])) {
                $nrorgPrincipal = $userData['ORGANIZATION']['NRORGPRINCIPAL'];
                $userData['USER']['ORGANIZATION_ID'] = $nrorgPrincipal;
                $userData['USER']['NRORG'] = $nrorgPrincipal;
                $userData['USER']['NRORGSUP'] = $nrorgPrincipal;
                $userData['USER']['NRORGTRAB'] = $nrorgPrincipal;
            }
            $userData['ACCESS_PROFILE'] = [];
            $this->getOtherSessionValues($supportOperator, $userData);
            $userData['IP_RESTRICTION']['USES_IP_RESTRICTION'] = 'N';
            $userData['PASSWORD_PARAMETERS'] = false;
        }
        return $userData;
    }

    protected function getOtherSessionValues($operator, &$userData) {
        $generalParams = RepositoryInstance::getParamgeral()->getParamGeralByNrorgToSupportOperator($operator['NRORGSUP']);
        $filial = RepositoryInstance::getFilial()->getFilialByCdfilialAndNrorgToSupportOperator($operator['CDFILIALSELECIONADA'], $operator['NRORGSUP']);
        $admUser = true;

        $userData['OTHER_SESSION_VALUES']['CDPICTPROD']        = isset($generalParams['CDPICTPROD']) ? $generalParams['CDPICTPROD'] : null;
        $userData['OTHER_SESSION_VALUES']['CDPICTPRAT']        = isset($generalParams['CDPICTPRAT']) ? $generalParams['CDPICTPRAT'] : null;
        $userData['OTHER_SESSION_VALUES']['IDUTCTRLACESWEB']   = isset($generalParams['IDUTCTRLACESWEB']) ? $generalParams['IDUTCTRLACESWEB'] : 'N';
        $userData['OTHER_SESSION_VALUES']['IDIDIOMA']          = $operator['IDIDIOMA'];
        $userData['OTHER_SESSION_VALUES']['NRESTRUTTRAB']      = $operator['NRESTRUTTRAB'];
        $userData['OTHER_SESSION_VALUES']['CDEMPRESA']         = $operator['CDEMPRESA'];
        $userData['OTHER_SESSION_VALUES']['NMACESSO']          = $operator['NMACESSO'];
        $userData['OTHER_SESSION_VALUES']['NMCOMPLOPER']       = $operator['NMCOMPLOPER'];
        $userData['OTHER_SESSION_VALUES']['NRPARCNEGOCIO']     = $operator['NRPARCNEGOCIO'];
        $userData['OTHER_SESSION_VALUES']['ACL_ADMINISTRATOR'] = $admUser;
        
        if(!empty($userData['ORGANIZATION']) && !empty($userData['ORGANIZATION']['NRORGPRINCIPAL'])) {
            $userData['OTHER_SESSION_VALUES']['NRORGTRAB'] = $userData['ORGANIZATION']['NRORGPRINCIPAL'];
        } else {
            $userData['OTHER_SESSION_VALUES']['NRORGTRAB'] = $operator['NRORGTRAB'];
        }
        
        if(isset($filial['CDFILIAL'])) {
            $userData['OTHER_SESSION_VALUES']['CDFILIAL']  = $filial['CDFILIAL'];
            $userData['OTHER_SESSION_VALUES']['NMFILIAL']  = $filial['NMFILIAL'];
        }
    }

    public function validateUser($cdoperador, $password)
    {
        $userValidationData = array(
            'PASSWORD' => true
        );
        $operador = RepositoryInstance::getOperador()->findOperadorByCdoperador($cdoperador);
        if($operador['CDSENHAOPERSUP'] != md5($password)) {
            $userValidationData['PASSWORD'] = false;
        }
        $userValidationData['EXPIRATION_DATE'] = $this->validateSupportOperatorAccess($operador['DTLIMACESSOSUP']);
        return $userValidationData;
    }
}